@@ -912,6 +912,17 @@ async def set_chat_administrator_custom_title(token, chat_id, user_id, custom_ti
     return await _process_request(token, method_url, params=payload, method='post')
 
 
+async def ban_chat_sender_chat(token, chat_id, sender_chat_id):
+    method_url = 'banChatSenderChat'
+    payload = {'chat_id': chat_id, 'sender_chat_id': sender_chat_id}
+    return await _process_request(token, method_url, params=payload, method='post')
+
+
+async def unban_chat_sender_chat(token, chat_id, sender_chat_id):
+    method_url = 'unbanChatSenderChat'
+    payload = {'chat_id': chat_id, 'sender_chat_id': sender_chat_id}
+    return await _process_request(token, method_url, params=payload, method='post')
+
 async def set_chat_permissions(token, chat_id, permissions):
     method_url = 'setChatPermissions'
     payload = {
